@@ -1,3 +1,5 @@
+import pyqrcode
+import qrtools
 import random
 import base64
 import json
@@ -7,6 +9,11 @@ from hashlib import sha1
 __all__ = ['encrypt', 'decrypt', 'encrypt_json', 'decrypt_json']
 
 
+def from_qrcode(filepath: str) -> str:
+    qr = qrtools.QR()
+    qr.decode(filepath)
+
+
 def crypt(data: str, key: bytes) -> str:
     """RC4 algorithm"""
     x = 0
@@ -52,6 +59,10 @@ def decrypt_json(data: str, key: str) -> dict:
     return json.loads(decrypt(data, key))
 
 
+def encode_qr(data: str, filepath='encrypted.png'):
+    return pyqrcode.create(data).png(filepath)
+
+
 def main():
     '''
     >>> for i in range(10):
@@ -71,16 +82,26 @@ def main():
     True
     '''
     import sys
-    argv = sys.argv
-    if argv[1] == 'encrypt':
-        return encrypt(argv[2], argv[3])
-    if argv[1] == 'decrypt':
-        return decrypt(argv[2], argv[3])
-    else:
-        return '''Options:
+
+    __doc__ = '''Options:
+        pyrc4 encrypt2qr data key filepath
         pyrc4 encrypt data key
         pyrc4 decrypt data key'''
 
+    argv = sys.argv
+
+    if len(argv) == 1:
+        return __doc__
+    if argv[1] == 'encrypt':
+        return encrypt(argv[2], argv[3]).decode()
+    if argv[1] == 'decrypt':
+        return decrypt(argv[2], argv[3])
+    if argv[1] == 'encrypt2qr':
+        return encode_qr(encrypt(argv[2], argv[3]))
+    else:
+        return __doc__
+
+
 if __name__ == '__main__':
     import doctest
     doctest.testmod()
